errors

package
v0.4.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 3, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewErrorDeleteFailed

func NewErrorDeleteFailed(apiError https.ApiError) error

NewErrorDeleteFailed is a constructor for ErrorDeleteFailed. It creates and returns a pointer to a new ErrorDeleteFailed instance with the given statusCode and body.

func NewResponseDetailString

func NewResponseDetailString(apiError https.ApiError) error

NewResponseDetailString is a constructor for ResponseDetailString. It creates and returns a pointer to a new ResponseDetailString instance with the given statusCode and body.

func NewResponseHttp400

func NewResponseHttp400(apiError https.ApiError) error

NewResponseHttp400 is a constructor for ResponseHttp400. It creates and returns a pointer to a new ResponseHttp400 instance with the given statusCode and body.

func NewResponseHttp401Error added in v0.2.38

func NewResponseHttp401Error(apiError https.ApiError) error

NewResponseHttp401Error is a constructor for ResponseHttp401Error. It creates and returns a pointer to a new ResponseHttp401Error instance with the given statusCode and body.

func NewResponseHttp403Error added in v0.2.38

func NewResponseHttp403Error(apiError https.ApiError) error

NewResponseHttp403Error is a constructor for ResponseHttp403Error. It creates and returns a pointer to a new ResponseHttp403Error instance with the given statusCode and body.

func NewResponseHttp404

func NewResponseHttp404(apiError https.ApiError) error

NewResponseHttp404 is a constructor for ResponseHttp404. It creates and returns a pointer to a new ResponseHttp404 instance with the given statusCode and body.

func NewResponseHttp429Error added in v0.2.38

func NewResponseHttp429Error(apiError https.ApiError) error

NewResponseHttp429Error is a constructor for ResponseHttp429Error. It creates and returns a pointer to a new ResponseHttp429Error instance with the given statusCode and body.

func NewResponseInventoryError added in v0.3.9

func NewResponseInventoryError(apiError https.ApiError) error

NewResponseInventoryError is a constructor for ResponseInventoryError. It creates and returns a pointer to a new ResponseInventoryError instance with the given statusCode and body.

func NewResponseLoginFailure

func NewResponseLoginFailure(apiError https.ApiError) error

NewResponseLoginFailure is a constructor for ResponseLoginFailure. It creates and returns a pointer to a new ResponseLoginFailure instance with the given statusCode and body.

func NewResponseSelfOauthLinkFailure

func NewResponseSelfOauthLinkFailure(apiError https.ApiError) error

NewResponseSelfOauthLinkFailure is a constructor for ResponseSelfOauthLinkFailure. It creates and returns a pointer to a new ResponseSelfOauthLinkFailure instance with the given statusCode and body.

Types

type ErrorDeleteFailed

type ErrorDeleteFailed struct {
	https.ApiError
	Detail string    `json:"detail"`
	OrgId  uuid.UUID `json:"org_id"`
}

ErrorDeleteFailed is a custom error.

func (ErrorDeleteFailed) Error

func (e ErrorDeleteFailed) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ErrorDeleteFailed.

type ResponseDetailString

type ResponseDetailString struct {
	https.ApiError
	Detail *string `json:"detail,omitempty"`
}

ResponseDetailString is a custom error.

func (ResponseDetailString) Error

func (r ResponseDetailString) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ResponseDetailString.

type ResponseHttp400

type ResponseHttp400 struct {
	https.ApiError
	Detail *string `json:"detail,omitempty"`
}

ResponseHttp400 is a custom error.

func (ResponseHttp400) Error

func (r ResponseHttp400) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ResponseHttp400.

type ResponseHttp401Error added in v0.2.38

type ResponseHttp401Error struct {
	https.ApiError
	Detail *string `json:"detail,omitempty"`
}

ResponseHttp401Error is a custom error.

func (ResponseHttp401Error) Error added in v0.2.38

func (r ResponseHttp401Error) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ResponseHttp401Error.

type ResponseHttp403Error added in v0.2.38

type ResponseHttp403Error struct {
	https.ApiError
	Detail *string `json:"detail,omitempty"`
}

ResponseHttp403Error is a custom error.

func (ResponseHttp403Error) Error added in v0.2.38

func (r ResponseHttp403Error) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ResponseHttp403Error.

type ResponseHttp404

type ResponseHttp404 struct {
	https.ApiError
	Id *string `json:"id,omitempty"`
}

ResponseHttp404 is a custom error.

func (ResponseHttp404) Error

func (r ResponseHttp404) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ResponseHttp404.

type ResponseHttp429Error added in v0.2.38

type ResponseHttp429Error struct {
	https.ApiError
	Detail *string `json:"detail,omitempty"`
}

ResponseHttp429Error is a custom error.

func (ResponseHttp429Error) Error added in v0.2.38

func (r ResponseHttp429Error) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ResponseHttp429Error.

type ResponseInventoryError added in v0.3.9

type ResponseInventoryError struct {
	https.ApiError
	Added               []string                                           `json:"added,omitempty"`
	Duplicated          []string                                           `json:"duplicated,omitempty"`
	MError              []string                                           `json:"error,omitempty"`
	InventoryAdded      []models.ResponseInventoryInventoryAddedItems      `json:"inventory_added,omitempty"`
	InventoryDuplicated []models.ResponseInventoryInventoryDuplicatedItems `json:"inventory_duplicated,omitempty"`
	Reason              []string                                           `json:"reason,omitempty"`
}

ResponseInventoryError is a custom error.

func (ResponseInventoryError) Error added in v0.3.9

func (r ResponseInventoryError) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ResponseInventoryError.

type ResponseLoginFailure

type ResponseLoginFailure struct {
	https.ApiError
	Detail     string  `json:"detail"`
	ForwardUrl *string `json:"forward_url,omitempty"`
}

ResponseLoginFailure is a custom error.

func (ResponseLoginFailure) Error

func (r ResponseLoginFailure) Error() string

Error implements the Error method for the error interface. It returns a formatted error message for ResponseLoginFailure.

type ResponseSelfOauthLinkFailure

type ResponseSelfOauthLinkFailure struct {
	https.ApiError
	MError           string `json:"error"`
	ErrorDescription string `json:"error_description"`
}

ResponseSelfOauthLinkFailure is a custom error.

func (ResponseSelfOauthLinkFailure) Error

Error implements the Error method for the error interface. It returns a formatted error message for ResponseSelfOauthLinkFailure.

Jump to